@@ -8,6 +8,8 @@ def add_standard_imports(doctest_namespace, tmpdir):
     import pint
     import xarray as xr
 
+    import pint_xarray
+
     ureg = pint.UnitRegistry(force_ndarray_like=True)
 
     doctest_namespace["np"] = np
@@ -15,6 +17,7 @@ def add_standard_imports(doctest_namespace, tmpdir):
     doctest_namespace["xr"] = xr
     doctest_namespace["pint"] = pint
     doctest_namespace["ureg"] = ureg
+    doctest_namespace["pint_xarray"] = pint_xarray
 
     # always seed numpy.random to make the examples deterministic
     np.random.seed(0)
